require 'wcc/styles/simple_form/asset_input'
require 'wcc/styles/simple_form/time_picker_input'
require 'wcc/styles/simple_form/date_picker_input'
require 'wcc/styles/simple_form/historical_date_input'
require 'wcc/styles/simple_form/string_array_input'

SimpleForm::FormBuilder.map_type :date, to: WCC::Styles::SimpleForm::DatePickerInput
SimpleForm::FormBuilder.map_type :datetime, :time, to: WCC::Styles::SimpleForm::TimePickerInput

SimpleForm.setup do |config|
  config.button_class = 'button'
  config.boolean_label_class = nil if config.respond_to?(:boolean_label_class=)
  config.boolean_style = :inline
  config.item_wrapper_tag = :div
  config.label_text = lambda { |label, required, explicit_label| "#{label.to_s.titleize}" }
  config.default_form_class = "simple_form row"
  config.browser_validations = false

  config.wrappers :watermark,
    tag: 'div',
    class: 'field-group',
    error_class: 'invalid' do |b|

    b.use :html5
    b.use :min_max
    b.use :maxlength
    b.use :placeholder

    b.optional :pattern
    b.optional :readonly

    b.use :label_input
    b.use :error, wrap_with: { tag: 'div', class: 'field-help text-danger' }
    b.use :hint,  wrap_with: { tag: 'div', class: 'field-help' }
  end

  config.wrappers :watermark_radio_buttons,
    tag: 'div',
    class: 'field-group radio-buttons',
    error_class: :invalid do |b|

    b.use :html5
    b.optional :readonly

    b.use :label, wrap_with: { tag: 'div', class: 'radio-heading' }
    b.use :input
    b.use :error, wrap_with: { tag: 'div', class: 'field-help text-danger' }
    b.use :hint,  wrap_with: { tag: 'div', class: 'field-help' }
  end

  config.wrappers :watermark_boolean,
    tag: 'div',
    class: 'field-group boolean' do |b|

    b.use :html5

    b.wrapper class: 'checkbox', error_class: 'invalid' do |ba|
      ba.use :input
      ba.use :label
    end
    b.use :error, wrap_with: { tag: 'div', class: 'field-help text-danger' }
    b.use :hint,  wrap_with: { tag: 'div', class: 'field-help' }

  end

  config.wrappers :watermark_check_boxes,
    tag: 'div',
    class: 'field-group checkboxes',
    error_class: 'invalid' do |b|

    b.use :html5

    b.use :label, wrap_with: { tag: 'div', class: 'checkbox-heading' }
    b.use :input
    b.use :error, wrap_with: { tag: 'div', class: 'field-help text-danger' }
    b.use :hint,  wrap_with: { tag: 'div', class: 'field-help' }
  end

  config.wrappers :watermark_select,
    tag: 'div',
    class: 'field-group select',
    error_class: 'invalid' do |b|

    b.use :html5

    b.use :label
    b.use :input, wrap_with: { tag: 'div', class: 'select-style selectize' }
    b.use :error, wrap_with: { tag: 'div', class: 'field-help text-danger' }
    b.use :hint,  wrap_with: { tag: 'div', class: 'field-help' }
  end

  config.default_wrapper = :watermark

  config.wrapper_mappings = {
    check_boxes: :watermark_check_boxes,
    radio_buttons: :watermark_radio_buttons,
    select: :watermark_select,
    boolean: :watermark_boolean,
  }

  config.custom_inputs_namespaces << "WCC::Styles::SimpleForm"
end

